==> nextcloud-app-tasks-0.11.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/gl.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tarefas",
    "Important" : "Importante",
    "Today" : "Hoxe",
    "Week" : "Semana",
    "All" : "Todo",
    "Current" : "Actual",
    "Completed" : "Completado",
    "The Tasks app for Nextcloud" : "O aplicativo de Tarefas para o Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "Unha vez activado, no menú de aplicativos do Nextcloud aparecerá unha nova opción «Tarefas». Dende aí pode engadir e eliminar tarefas; editar o seu título, descrición e datas de inicio e remate, horarios de recordatorio; marcalas como importantes; e engadirlles comentarios. As tarefas poden compartirse entre usuarios. As tarefas poden sincronizarse usando CalDAv (cada lista de tarefas está ligada cun calendario do Nextcloud para sincronizalo co seu cliente local [Thunderbird, Evolution, KDE Kontact, iCal...]. Só hai que engadir o calendario como un calendario remoto no seu cliente). Pode descargar as súas tarefas como ficheiros ICS usando o botón de descarga para cada calendario.",
    "Share with users or groups" : "Compartir con usuarios ou grupos",
    "No users or groups" : "Non hai usuarios nin grupos",
    "can edit" : "pode editar",
    "Unable to delete the share." : "Non foi posíbel eliminar o recurso compartido",
    "Unable to change permissions." : "Non foi posíbel cambiar os permisos.",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "Delete all completed tasks." : "Eliminar todas as tarefas completadas.",
    "Delete completed tasks." : "Eliminar as tarefas completadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Eliminadas todas as tarefas completadas do calendario «{calendar}».",
    "No errors" : "Sen erros",
    "Open your browser console for more details" : "Abra a consola do navegador para obter máis detalles",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Isto eliminará {taskCount} tarefa completada e as súas subtarefas do calendario «{calendar}».","Isto eliminará {taskCount} tarefas completadas e as súas subtarefas do calendario «{calendar}»."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Non foi posíbel eliminar {failedCount} tarefa.","Non foi posíbel eliminar {failedCount} tarefas."],
    "Load all completed tasks." : "Cargar todas as tarefas completadas.",
    "Change sort order" : "Cambiar a ordenación",
    "Default" : "Predeterminado",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenar polo estado de completado, data de caducidade, prioridade, data de inicio e resumo.",
    "Due date" : "Data de caducidade",
    "Sort by due date and summary." : "Ordear por data de caducidade e resumo.",
    "Start date" : "Data de comezo",
    "Sort by start date and summary." : "Ordenar por data de inicio e resumo.",
    "Created date" : "Data de creación",
    "Sort by created date and summary." : "Ordenar por data de creación e resumo.",
    "Last modified" : "Última modificación",
    "Sort by last-modified date and summary." : "Ordenar por data de última modificación e resumo.",
    "Completed date" : "Data de completado",
    "Sort by completed date." : "Ordenar pola data de completado.",
    "Priority" : "Prioridade",
    "Sort by priority and summary." : "Ordenar por prioridade e resumo.",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordenar manualmente.",
    "Alphabetically" : "Alfabeticamente",
    "Sort by summary and priority." : "Ordenar por  resumo e prioridade.",
    "Task is completed" : "A tarefa está completada",
    "{complete} % completed" : "{complete} % completado",
    "Toggle visibility of completed subtasks." : "Ver/agochar as subtarefas completadas.",
    "Toggle visibility of all subtasks." : "Ver/agochar todas as subtarefas",
    "[Yesterday]" : "[Onte]",
    "[Today]" : "[Hoxe]",
    "[Tomorrow]" : "[Mañá]",
    "Add a subtask to \"{task}\"…" : "Engadir unha subtarefa a «{task}»…",
    "Add a task to \"{task}\"…" : "Engadir unha tarefa a «{task}»…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tarefa completada","%n tarefas completadas"],
    "Add an important task to \"{calendar}\"…" : "Engadir unha tarefa importante a «{calendar}»…",
    "Add a task due today to \"{calendar}\"…" : "Engadir unha tarefa que caduca hoxe a «{calendar}»…",
    "Add a current task to \"{calendar}\"…" : "Engadir  unha tarefa actual a «{calendar}»…",
    "Add a task to \"{calendar}\"…" : "Engadir unha tarefa a «{calendar}»…",
    "Tomorrow" : "Mañá",
    "Set start date" : "Estabelezer a data de comezo",
    "Set start time" : "Estabelezer a hora de comezo",
    "Set due date" : "Estabelecer a data de caducidade",
    "Set due time" : "Estabelecer a hora de caducidade",
    "All day" : "Todo o día",
    "Select a calendar" : "Seleccione un calendario.",
    "Select a classification" : "Seleccione unha clasificación",
    "Select categories" : "Seleccionar categorías",
    "Add this as a new category" : "Engadir isto como unha nova categoría",
    "Task not found!" : "Non se atopou a tarefa!",
    "[Starts today]" : "[Comeza hoxe]",
    "[Starts tomorrow]" : "[Comeza mañá]",
    "[Starts on] LL" : "[Comeza o] LL",
    "[Started yesterday]" : "[Comezou onte]",
    "[Started on] LL" : "[Comezou o] LL",
    "[Started today at] LT" : "[Comezou hoxe ás] LT",
    "[Starts today at] LT" : "[Comeza hoxe ás] LT",
    "[Starts tomorrow at] LT" : "[Comeza mañá ás] LT",
    "[Starts on] LL [at] LT" : "[Comeza o] LL [ás] LT",
    "[Started yesterday at] LT" : "[Comezou onte ás] LT",
    "[Started on] LL [at] LT" : "[Comezou o] LL [ás] LT",
    "[Due today]" : "[Remata hoxe]",
    "[Due tomorrow]" : "[Remata mañá]",
    "[Due on] LL" : "[Remata o] LL",
    "[Was due yesterday]" : "[Rematou onte]",
    "[Was due on] LL" : "[Rematou o] LL",
    "[Was due today at] LT" : "[Rematou hoxe ás] LT",
    "[Due today at] LT" : "[Remata hoxe ás] LT",
    "[Due tomorrow at] LT" : "[Remata mañá ás] LT",
    "[Due on] LL [at] LT" : "[Remata o] LL [ás] LT",
    "[Was due yesterday at] LT" : "[Rematou onte ás] LT",
    "[Was due on] LL [at] LT" : "[Rematou o] LL [ás] LT",
    "No priority assigned" : "Sen asignar prioridade",
    "Priority {priority}: high" : "Prioridade {priority}: alta",
    "Priority {priority}: medium" : "Prioridade {priority}: media",
    "Priority {priority}: low" : "Prioridade {priority}: baixa",
    "{percent} % completed" : "{percent} % completado",
    "When shared show full event" : "Amosar o evento completo ao compartir",
    "When shared show only busy" : "Amosar só o ocupado ao compartir",
    "When shared hide this event" : "Agochar este evento ao compartir",
    "Completed {date}" : "Completado o {date}",
    "Created {date}" : "Creado o {date}",
    "Last modified {date}" : "Última modificación o {date}",
    "Edit" : "Editar",
    "Copy private link" : "Copiar a ligazón privada",
    "Copied" : "Copiada",
    "Can not copy" : "Non se pode copiar",
    "Download" : "Descargar",
    "Save" : "Gardar",
    "Add List…" : "Engadir unha lista...",
    "New List" : "Lista nova",
    "Calendar link copied to clipboard." : "Ligazón do calendario copiada no portapapeis.",
    "Calendar link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón do calendario no portapapeis.",
    "The name \"{calendar}\" is already used." : "O nome «{calendar}» xa esta a ser usado.",
    "An empty name is not allowed." : "Non está permitido deixar baleiro o campo nome",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Isto eliminará o calendario «{calendar}» e todos os seus eventos e tarefas correspodentes.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidade","Compartido con {num} entidades"],
    "Settings" : "Axustes",
    "Default list" : "Lista predeterminada",
    "Visibility of Smart Collections" : "Visibilidade das coleccións intelixentes",
    "Hidden" : "Agochado",
    "Visible" : "Visíbel",
    "Automatic" : "Automatico",
    "Could not delete the task." : "Non foi posíbel eliminar a tarefa",
    "Synchronizing to the server." : "Sincronizando co servidor.",
    "Task successfully saved to server." : "A tarefa foi gardada satisfactoriamente no servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Non foi posíbel actualizar a tarefa porque foi modificada no servidor. Prema para actualizala, os cambios locais serán desbotados.",
    "Could not update the task." : "Non foi posíbel actualizar a tarefa",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discared." : "Non foi posíbel actualizar a tarefa porque foi modificada no servidor. Prema para actualizala, os cambios locais serán desbotados.",
    "An error occurred" : "Produciuse un erro"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/gl.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoxe",
    "Week" : "Semana",
    "All" : "Todo",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tarefas",
    "The Tasks app for Nextcloud" : "A aplicación de Tarefas para o Nextcloud",
    "Default list" : "Lista predeterminada",
    "Visibility of Smart Collections" : "Visibilidade das coleccións intelixentes",
    "Hidden" : "Agochado",
    "Visible" : "Visíbel",
    "Automatic" : "Automatico",
    "Share with users or groups" : "Compartir con usuarios ou grupos",
    "No users or groups" : "Non hai usuarios nin grupos",
    "Unshare with {displayName}" : "Deixar de compartir con {displayName}",
    "Unable to delete the share." : "Non foi posíbel eliminar o recurso compartido",
    "Unable to change permissions." : "Non foi posíbel cambiar os permisos.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar a ligazón privada",
    "Copied" : "Copiada",
    "Cannot copy" : "Non se pode copiar",
    "Delete" : "Eliminar",
    "Unshare" : "Deixar de compartir",
    "Cancel" : "Cancelar",
    "Save" : "Gardar",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Isto eliminará o calendario «{calendar}» e todos os seus eventos e tarefas correspodentes.",
    "This will unshare the calendar \"{calendar}\"." : "Isto deixará de compartir o calendario «{calendar}».",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Isto eliminará a lista «{list}» e todas as tarefas correspondentes.",
    "This will unshare the list \"{list}\"." : "Isto deixará de compartir a lista «{list}».",
    "Calendar link copied to clipboard." : "A ligazón do calendario foi copiada no portapapeis.",
    "List link copied to clipboard." : "A ligazón da lista foi copiada ao portapapeis.",
    "Calendar link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón do calendario no portapapeis.",
    "List link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón da lista no portapapeis.",
    "The name \"{calendar}\" is already used." : "O nome «{calendar}» xa esta a ser usado.",
    "An empty name is not allowed." : "Non está permitido deixar baleiro o campo nome",
    "An error occurred, unable to delete the calendar." : "Produciuse un erro, non é posíbel eliminar o calendario.",
    "An error occurred, unable to delete the list." : "Produciuse un erro, non é posíbel eliminar a lista.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminar o calendario en {countdown} segundo","Eliminar o calendario en {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixar de compartir o calendario en {countdown} segundo","Deixar de compartir o calendario en {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Eliminando a lista en {countdown} segundo","Eliminando a lista en {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Deixar de compartir a lista en {countdown} segundo","Deixar de compartir a lista en {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidade","Compartido con {num} entidades"],
    "Delete all completed tasks." : "Eliminar todas as tarefas completadas.",
    "Delete completed tasks." : "Eliminar as tarefas completadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Eliminadas todas as tarefas completadas do calendario «{calendar}».",
    "No errors" : "Sen erros",
    "Open your browser console for more details" : "Abra a consola do navegador para obter máis detalles",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Isto eliminará {taskCount} tarefa completada e as súas subtarefas do calendario «{calendar}».","Isto eliminará {taskCount} tarefas completadas e as súas subtarefas do calendario «{calendar}»."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Non foi posíbel eliminar {failedCount} tarefa.","Non foi posíbel eliminar {failedCount} tarefas."],
    "Add an important task to \"{calendar}\"…" : "Engadir unha tarefa importante a «{calendar}»…",
    "Add a task due today to \"{calendar}\"…" : "Engadir unha tarefa que caduca hoxe a «{calendar}»…",
    "Add a current task to \"{calendar}\"…" : "Engadir  unha tarefa actual a «{calendar}»…",
    "Add a task to \"{calendar}\"…" : "Engadir unha tarefa a «{calendar}»…",
    "Load all completed tasks." : "Cargar todas as tarefas completadas.",
    "Change sort order" : "Cambiar o criterio de ordenación",
    "Relevance" : "Relevancia",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenar polo estado de completado, data de caducidade, prioridade, data de inicio e resumo.",
    "Start date" : "Data de comezo",
    "Sort by start date and summary." : "Ordenar por data de inicio e resumo.",
    "Due date" : "Data de caducidade",
    "Sort by due date and summary." : "Ordear por data de caducidade e resumo.",
    "Created date" : "Data de creación",
    "Sort by created date and summary." : "Ordenar por data de creación e resumo.",
    "Last modified" : "Última modificación",
    "Sort by last-modified date and summary." : "Ordenar por data de última modificación e resumo.",
    "Completed date" : "Data de completado",
    "Sort by completed date." : "Ordenar pola data de completado.",
    "Priority" : "Prioridade",
    "Sort by priority and summary." : "Ordenar por prioridade e resumo.",
    "Alphabetically" : "Alfabeticamente",
    "Sort by summary and priority." : "Ordenar por  resumo e prioridade.",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordenar manualmente.",
    "{complete} % completed" : "{complete} % completado",
    "Add subtask" : "Engadir unha subtarefa",
    "Show subtasks" : "Amosar as subtarefas",
    "Hide subtasks" : "Agochar as subtarefas",
    "Delete task" : "Eliminar tarefa",
    "[Yesterday]" : "[Onte]",
    "[Today]" : "[Hoxe]",
    "[Tomorrow]" : "[Mañá]",
    "[Completed yesterday]" : "[Completado onte]",
    "[Completed today]" : "[Completado hoxe]",
    "[Completed tomorrow]" : "[Completado mañá]",
    "[Yesterday at] LT" : "[Onte ás] LT",
    "[Today at] LT" : "[Hoxe ás] LT",
    "[Tomorrow at] LT" : "[Mañá ás] LT",
    "L [at] LT" : "L [ás] LT",
    "[Completed yesterday at] LT" : "[Completado onte ás] LT",
    "[Completed today at] LT" : "[Completado hoxe ás] LT",
    "[Completed tomorrow at] LT" : "[Completado mañá ás] LT",
    "[Completed] L [at] LT" : "[Completado] L [ás] LT",
    "Add a subtask to \"{task}\"…" : "Engadir unha subtarefa a «{task}»…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Eliminando a tarefa en {countdown} segundo","Eliminando a tarefa en {countdown} segundos"],
    "Task is completed" : "A tarefa está completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tarefa completada","%n tarefas completadas"],
    "Tomorrow" : "Mañá",
    "Add List…" : "Engadir unha lista...",
    "New List" : "Lista nova",
    "All day" : "Todo o día",
    "Select a classification" : "Seleccione unha clasificación",
    "Select a status" : "Seleccionar un estado",
    "When shared show full event" : "Amosar o evento completo ao compartir",
    "When shared show only busy" : "Amosar só o ocupado ao compartir",
    "When shared hide this event" : "Agochar este evento ao compartir",
    "Needs action" : "Necesita unha acción",
    "In process" : "En proceso",
    "Canceled" : "Cancelado",
    "Loading task from server." : "Cargando tarefas dende o servidor.",
    "Task not found!" : "Non se atopou a tarefa!",
    "[Starts today]" : "[Comeza hoxe]",
    "[Starts tomorrow]" : "[Comeza mañá]",
    "[Starts on] LL" : "[Comeza o] LL",
    "[Started yesterday]" : "[Comezou onte]",
    "[Started on] LL" : "[Comezou o] LL",
    "[Started today at] LT" : "[Comezou hoxe ás] LT",
    "[Starts today at] LT" : "[Comeza hoxe ás] LT",
    "[Starts tomorrow at] LT" : "[Comeza mañá ás] LT",
    "[Starts on] LL [at] LT" : "[Comeza o] LL [ás] LT",
    "[Started yesterday at] LT" : "[Comezou onte ás] LT",
    "[Started on] LL [at] LT" : "[Comezou o] LL [ás] LT",
    "Set start date" : "Estabelezer a data de comezo",
    "[Due today]" : "[Remata hoxe]",
    "[Due tomorrow]" : "[Remata mañá]",
    "[Due on] LL" : "[Remata o] LL",
    "[Was due yesterday]" : "[Rematou onte]",
    "[Was due on] LL" : "[Rematou o] LL",
    "[Was due today at] LT" : "[Rematou hoxe ás] LT",
    "[Due today at] LT" : "[Remata hoxe ás] LT",
    "[Due tomorrow at] LT" : "[Remata mañá ás] LT",
    "[Due on] LL [at] LT" : "[Remata o] LL [ás] LT",
    "[Was due yesterday at] LT" : "[Rematou onte ás] LT",
    "[Was due on] LL [at] LT" : "[Rematou o] LL [ás] LT",
    "Set due date" : "Estabelecer a data de caducidade",
    "Priority {priority}: low" : "Prioridade {priority}: baixa",
    "Priority {priority}: medium" : "Prioridade {priority}: media",
    "Priority {priority}: high" : "Prioridade {priority}: alta",
    "No priority assigned" : "Sen asignar prioridade",
    "{percent} % completed" : "{percent} % completado",
    "Successfully created the task." : "A tarefa foi creada satisfactoriamente.",
    "Could not delete the task." : "Non foi posíbel eliminar a tarefa",
    "Synchronizing to the server." : "Sincronizando co servidor.",
    "Task successfully saved to server." : "A tarefa foi gardada satisfactoriamente no servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Non foi posíbel actualizar a tarefa porque foi modificada no servidor. Prema para actualizala, os cambios locais serán desbotados.",
    "Could not update the task." : "Non foi posíbel actualizar a tarefa",
    "Successfully updated the task." : "A tarefa foi actualizada satisfactoriamente.",
    "Task successfully moved to new calendar." : "A tarefa foi movida satisfactoriamente ao novo calendario.",
    "An error occurred" : "Produciuse un erro"
},
"nplurals=2; plural=(n != 1);");
